@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent qw/autobox/;
 
-our $VERSION = "1.004";
+our $VERSION = "1.005";
 
 =head1 NAME
 
@@ -171,7 +171,9 @@ use true;
 use Carp;
 
 sub import {
-    shift->SUPER::import( ARRAY => "autobox::Transform::Array" );
+    my $self = shift;
+    $self->SUPER::import( ARRAY => "autobox::Transform::Array" );
+    $self->SUPER::import( HASH  => "autobox::Transform::Hash"  );
 }
 
 sub throw {
@@ -184,10 +186,6 @@ sub throw {
 
 
 
-package # hide from PAUSE
-    autobox::Transform::Array;
-
-
 =head2 Transforming lists of objects vs list of hashrefs
 
 map_by, grep_by etc are called the same way regardless of whether the
@@ -232,6 +230,11 @@ context. E.g.
 
 =cut
 
+package # hide from PAUSE
+    autobox::Transform::Array;
+
+
+
 sub __invoke_by {
     my $invoke = shift;
     my $array = shift;
@@ -529,6 +532,68 @@ sub flat {
 
 
 
+
+
+=head1 AUTOBOX HASH METHODS
+
+=cut
+
+package # hide from PAUSE
+    autobox::Transform::Hash;
+
+
+sub key_value {
+    my $hash = shift;
+    my( $original_key, $new_key ) = @_;
+    $new_key //= $original_key;
+    my %key_value = ( $new_key => $hash->{$original_key} );
+    return wantarray ? %key_value : \%key_value;
+}
+
+sub __core_key_value_if {
+    my $hash = shift;
+    my( $comparison_sub, $original_key, $new_key ) = @_;
+    $comparison_sub->($hash, $original_key) or return wantarray ? () : {};
+    return key_value($hash, $original_key, $new_key)
+}
+
+sub key_value_if_exists {
+    my $hash = shift;
+    my( $original_key, $new_key ) = @_;
+    return __core_key_value_if(
+        $hash,
+        sub { !! exists shift->{ shift() } },
+        $original_key,
+        $new_key
+    );
+}
+
+sub key_value_if_true {
+    my $hash = shift;
+    my( $original_key, $new_key ) = @_;
+    return __core_key_value_if(
+        $hash,
+        sub { !! shift->{ shift() } },
+        $original_key,
+        $new_key
+    );
+}
+
+sub key_value_if_defined {
+    my $hash = shift;
+    my( $original_key, $new_key ) = @_;
+    return __core_key_value_if(
+        $hash,
+        sub { defined( shift->{ shift() } ) },
+        $original_key,
+        $new_key
+    );
+}
+
+
+
+
+
 =head1 DEVELOPMENT
 
 =head2 Author
